import { ElementRef, EventEmitter, OnChanges, OnInit, SimpleChanges } from '@angular/core';
export declare class AngularHourSliderComponent implements OnInit, OnChanges {
    startHour: number;
    endHour: number;
    hoursBetweenTick: number;
    incrementMinutes: number;
    initialValueAsHours: number;
    height: number;
    width: number;
    calculatedValueAsHours: number;
    selectedValue: EventEmitter<number>;
    ticks: number[];
    rangeMin: number;
    rangeMax: number;
    increment: number;
    initialValue: number;
    parentNativeElement: any;
    slider: any;
    d3Svg: any;
    scaler: any;
    handler: any;
    constructor(element: ElementRef);
    ngOnInit(): void;
    ngOnChanges(changes: SimpleChanges): void;
    /**
     * Takes {@code val} and maps it nicely to our plot floored to the closest {@link #increment} value.
     *
     * @param val - The value to bound
     * @returns The value bounded
     */
    _calculateBoundedValue: (val: any) => number;
    /**
     * Handles the dragging events of the {@link #handler}. Emits the {@code val} via
     * the {@link #selectedValue} as a bounded value to the plot.
     *
     * @param val - The value dragged to
     */
    _handleSlide: (val: any) => void;
    _handleSliderInterrupt: () => void;
    private renderPlot;
    /**
     * Determines our {@link #height} and {@link #width} for our
     * component.
     */
    determineDimensions(): void;
    /**
     * Populates the {@link #ticks} array for the plot graph
     */
    populateTicks(): void;
    private clearPlot;
    /**
     * Setups our {{svg}} template to the correct boundaries
     *
     * @returns
     */
    private renderSvgContainer;
    /**
     * Creates a {{d3.scaleLinear}} which maps x -> y where y is a bounded domain.
     *
     * @param width - The width of our main {{svg}}
     * @returns the {{d3.scaleLinear}}
     */
    private buildScaler;
    /**
     * Creates an {{svg}} {{g}} (group) that holds onto our entire {{d3}} component.
     *
     * @param svg - The main {{svg}} template
     * @param marginLeft
     * @param marginTop
     * @param height
     * @returns
     */
    private renderSlider;
    /**
     * Creates the line that our handler will slide on.
     *
     * @param slider - The main {{svg}} group
     * @param height - The hight of our {{svg}}
     */
    private renderPlotLine;
    /**
     * Creates the ticks on the plot.
     *
     * @param slider - The main {{svg}} group
     * @param height - The height of our {{svg}}
     */
    private renderPlotTicks;
    /**
     * Renders the "handle" the user interacts with to drag across the slider.
     *
     * The handle is an {{svg}} {{circle}} composed of two {{circle}}s
     *
     * @param height - The height of our {{svg}}
     * @returns A handle on our handler
     */
    private renderHandler;
    /**
     * Will nicely drag the {@link #handler} to the selected {@code value}.
     *
     * @param value - The value to slide to
     */
    slideToValue(value: number): void;
}
